network\_wrangler.Scenario
==========================

.. currentmodule:: network_wrangler

.. autoclass:: Scenario

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Scenario.__init__
      ~Scenario.add_project_card_from_file
      ~Scenario.add_project_cards_from_directory
      ~Scenario.add_project_cards_from_tags
      ~Scenario.applied_project_card_summary
      ~Scenario.apply_all_projects
      ~Scenario.apply_project
      ~Scenario.check_scenario_conflicts
      ~Scenario.check_scenario_requisites
      ~Scenario.create_base_scenario
      ~Scenario.create_scenario
      ~Scenario.get_project_names
      ~Scenario.order_project_cards
      ~Scenario.remove_all_projects
      ~Scenario.scenario_summary
   
   

   
   
   